import { OnInit } from '@angular/core';
import { EditorConfig } from '@dotcms/client';
import { DynamicComponentEntity } from '../../models';
import { DotCMSPageAsset } from '../../models/dotcms.model';
import * as i0 from "@angular/core";
/**
 * `DotcmsLayoutComponent` is a class that represents the layout for a DotCMS page.
 *  It includes a `pageAsset` property that represents the DotCMS page asset and a `components` property that represents the dynamic components for the page.
 *
 * @export
 * @class DotcmsLayoutComponent
 */
export declare class DotcmsLayoutComponent implements OnInit {
    /**
     * The `pageAsset` property represents the DotCMS page asset.
     *
     * @type {(DotCMSPageAsset)}
     * @memberof DotcmsLayoutComponent
     * @required
     */
    pageAsset: DotCMSPageAsset;
    /**
     * The `components` property is a record of dynamic components for each Contentlet on the page.
     *
     * @type {Record<string, DynamicComponentEntity>}
     * @memberof DotcmsLayoutComponent
     * @required
     */
    components: Record<string, DynamicComponentEntity>;
    /**
     * The `onReload` property is a function that reloads the page after changes are made.
     *
     * @memberof DotcmsLayoutComponent
     * @deprecated In future implementation we will be listening for the changes from the editor to update the page state so reload will not be needed.
     */
    onReload: () => void;
    /**
     *
     * @type {DotCMSFetchConfig}
     * @memberof DotCMSPageEditorConfig
     * @description The configuration custom params for data fetching on Edit Mode.
     * @example <caption>Example with Custom GraphQL query</caption>
     * <dotcms-layout [editor]="{ query: 'query { ... }' }"/>
     *
     * @example <caption>Example usage with Custom Page API parameters</caption>
     * <dotcms-layout [editor]="{ params: { depth: '2' } }"/>;
     */
    editor: EditorConfig;
    private readonly route;
    private readonly pageContextService;
    private readonly destroyRef$;
    private client;
    protected readonly pageAsset$: import("rxjs").Observable<DotCMSPageAsset | null>;
    ngOnInit(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DotcmsLayoutComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DotcmsLayoutComponent, "dotcms-layout", never, { "pageAsset": { "alias": "pageAsset"; "required": true; }; "components": { "alias": "components"; "required": true; }; "onReload": { "alias": "onReload"; "required": false; }; "editor": { "alias": "editor"; "required": false; }; }, {}, never, never, true, never>;
}
//# sourceMappingURL=dotcms-layout.component.d.ts.map